==> jc-1.4.0.tar.gz: polyglot/ast/Binary.h <==
// public abstract interface polyglot.ast.Binary

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class fb819a4019abba3a polyglot_ast_Binary

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_polyglot_ast_Binary_H_
#define _JC_polyglot_ast_Binary_H_

// Typedefs
typedef struct _jc_polyglot_ast_Binary$fields_struct	_jc_polyglot_ast_Binary$fields_struct;
typedef const struct _jc_polyglot_ast_Binary$vtype	_jc_polyglot_ast_Binary$vtype;

// Class fields structure
struct _jc_polyglot_ast_Binary$fields_struct {
	struct _jc_polyglot_ast_Binary__24Operator$object	*ADD;
	struct _jc_polyglot_ast_Binary__24Operator$object	*BIT__5fAND;
	struct _jc_polyglot_ast_Binary__24Operator$object	*BIT__5fOR;
	struct _jc_polyglot_ast_Binary__24Operator$object	*BIT__5fXOR;
	struct _jc_polyglot_ast_Binary__24Operator$object	*COND__5fAND;
	struct _jc_polyglot_ast_Binary__24Operator$object	*COND__5fOR;
	struct _jc_polyglot_ast_Binary__24Operator$object	*DIV;
	struct _jc_polyglot_ast_Binary__24Operator$object	*EQ;
	struct _jc_polyglot_ast_Binary__24Operator$object	*GE;
	struct _jc_polyglot_ast_Binary__24Operator$object	*GT;
	struct _jc_polyglot_ast_Binary__24Operator$object	*LE;
	struct _jc_polyglot_ast_Binary__24Operator$object	*LT;
	struct _jc_polyglot_ast_Binary__24Operator$object	*MOD;
	struct _jc_polyglot_ast_Binary__24Operator$object	*MUL;
	struct _jc_polyglot_ast_Binary__24Operator$object	*NE;
	struct _jc_polyglot_ast_Binary__24Operator$object	*SHL;
	struct _jc_polyglot_ast_Binary__24Operator$object	*SHR;
	struct _jc_polyglot_ast_Binary__24Operator$object	*SUB;
	struct _jc_polyglot_ast_Binary__24Operator$object	*USHR;
};
extern _jc_polyglot_ast_Binary$fields_struct _jc_polyglot_ast_Binary$class_fields;

// Static methods
extern void _jc_polyglot_ast_Binary$method$_clinit$a816641e0ba8bfef(_jc_env *);

// Vtype
struct _jc_polyglot_ast_Binary$vtype {
	_jc_type			type;
};

// Type structure
extern _jc_polyglot_ast_Binary$vtype _jc_polyglot_ast_Binary$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_ast_Binary, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_ast_Binary$class_object;

#endif	/* _JC_polyglot_ast_Binary_H_ */

==> jc-1.4.6.tar.gz: polyglot/ast/Binary.h <==
// public abstract interface polyglot.ast.Binary

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class fb819a4019abba3a polyglot_ast_Binary

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_polyglot_ast_Binary_H_
#define _JC_polyglot_ast_Binary_H_

// Typedefs
typedef struct _jc_polyglot_ast_Binary$fields_struct	_jc_polyglot_ast_Binary$fields_struct;
typedef const struct _jc_polyglot_ast_Binary$vtype	_jc_polyglot_ast_Binary$vtype;

// Class fields structure
struct _jc_polyglot_ast_Binary$fields_struct {
	struct _jc_polyglot_ast_Binary__24Operator$object	*ADD;
	struct _jc_polyglot_ast_Binary__24Operator$object	*BIT__5fAND;
	struct _jc_polyglot_ast_Binary__24Operator$object	*BIT__5fOR;
	struct _jc_polyglot_ast_Binary__24Operator$object	*BIT__5fXOR;
	struct _jc_polyglot_ast_Binary__24Operator$object	*COND__5fAND;
	struct _jc_polyglot_ast_Binary__24Operator$object	*COND__5fOR;
	struct _jc_polyglot_ast_Binary__24Operator$object	*DIV;
	struct _jc_polyglot_ast_Binary__24Operator$object	*EQ;
	struct _jc_polyglot_ast_Binary__24Operator$object	*GE;
	struct _jc_polyglot_ast_Binary__24Operator$object	*GT;
	struct _jc_polyglot_ast_Binary__24Operator$object	*LE;
	struct _jc_polyglot_ast_Binary__24Operator$object	*LT;
	struct _jc_polyglot_ast_Binary__24Operator$object	*MOD;
	struct _jc_polyglot_ast_Binary__24Operator$object	*MUL;
	struct _jc_polyglot_ast_Binary__24Operator$object	*NE;
	struct _jc_polyglot_ast_Binary__24Operator$object	*SHL;
	struct _jc_polyglot_ast_Binary__24Operator$object	*SHR;
	struct _jc_polyglot_ast_Binary__24Operator$object	*SUB;
	struct _jc_polyglot_ast_Binary__24Operator$object	*USHR;
};
extern _jc_polyglot_ast_Binary$fields_struct _jc_polyglot_ast_Binary$class_fields;

// Static methods
extern void _jc_polyglot_ast_Binary$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;

// Vtype
struct _jc_polyglot_ast_Binary$vtype {
	_jc_type			type;
};

// Type structure
extern _jc_polyglot_ast_Binary$vtype _jc_polyglot_ast_Binary$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_ast_Binary, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_ast_Binary$class_object;

#endif	/* _JC_polyglot_ast_Binary_H_ */
